Modules
Structs
Enums
- Send
Error - Error result value when attempting to send an XCM message.
Constants
Traits
- Provide
Asset Price - Release
Schedule - A release schedule over a fungible. This allows a particular fungible to have release limits applied to it.
- SendXcm
- Utility for sending an XCM message to a given location.
Type Aliases
- QueryId
- An identifier for a query.
- Send
Result - Result value when attempting to send an XCM message.
- Xcm
- The basic concrete type of
Xcm, which doesn’t make any assumptions about the format of a call other than it is pre-encoded. - XcmHash
- A hash type for identifying messages.